# Basics

*Briefly talk about how basic concepts fit together here...*

Before diving into the details, please read [the design principles](./design.md) to help you better understand why things are organized in such way.
